==> humhub-1.15.3.tar.gz: humhub-1.15.3/protected/humhub/modules/space/messages/eu/manage.php <==
<?php
return array (
  '-' => '',
  '<strong>Create</strong> Space' => '',
  '<strong>Manage</strong> members' => '',
  '<strong>Members</strong>' => '',
  '<strong>Security</strong> settings' => '',
  '<strong>Space</strong> Modules' => '',
  '<strong>Space</strong> settings' => '',
  'Actions' => 'Ekintzak',
  'Activate' => 'Aktibatu',
  'Add <strong>Modules</strong>' => '',
  'Advanced access settings' => '',
  'All members excluding moderators and administrators of this Space will be removed. All pending invitations and membership requests will be terminated.' => '',
  'Archive' => '',
  'Are you sure you want to remove this member.' => '',
  'Are you sure, that you want to delete this space? All published content will be removed!' => '',
  'As owner of this space you can transfer this role to another administrator in space.' => '',
  'Cancel Membership' => '',
  'Choose if new content should be public or private by default' => '',
  'Choose the kind of membership you want to provide for this workspace.' => '',
  'Choose the modules you want to use for this Space. If you are undecided, you can also activate them later on via the Space settings.' => '',
  'Choose the modules you want to use for this Space. In order for the modules to be available to you here, they must have been previously installed by administrators of the network using the admin panel. If you cannot deactivate individual modules, it is because they have been set as the default for the entire network.' => '',
  'Choose the security level for this workspace to define the visibleness.' => '',
  'Currently there are no modules available for this space!' => '',
  'Delete' => 'Ezabatu',
  'Don\'t receive notifications for new content' => '',
  'Hide posts on dashboard' => '',
  'Invited By' => '',
  'Members' => '',
  'Modules' => 'Moduluak',
  'Next' => 'Hurrengoa',
  'Only global administrators can change this value' => '',
  'Owner' => '',
  'Pending Approvals' => '',
  'Pending Invites' => '',
  'Permissions are assigned to different user-roles. To edit a permission, select the user-role you want to edit and change the drop-down value of the given permission.' => '',
  'Please type the name of the space to proceed.' => '',
  'Receive Notifications for new content' => '',
  'Removal of members queued' => '',
  'Remove all members' => '',
  'Remove from space' => '',
  'Role' => '',
  'Security' => '',
  'Show all' => '',
  'Show posts on dashboard' => '',
  'Space name' => '',
  'Space owner' => '',
  'Stream (Default)' => '',
  'The URL has already been taken.' => '',
  'The url contains illegal characters!' => '',
  'This option will hide new content from this space at your dashboard' => '',
  'This option will show new content from this space at your dashboard' => '',
  'Transfer ownership' => '',
  'Unarchive' => '',
  'e.g. example for {baseUrl}/s/example' => '',
  'never' => '',
);

==> humhub-1.16.2.tar.gz: humhub-1.16.2/protected/humhub/modules/space/messages/eu/manage.php <==
<?php
return array (
  '-' => '',
  '<strong>Create</strong> Space' => '',
  '<strong>Manage</strong> members' => '',
  '<strong>Members</strong>' => '',
  '<strong>Security</strong> settings' => '',
  '<strong>Space</strong> Modules' => '',
  '<strong>Space</strong> settings' => '',
  'Actions' => 'Ekintzak',
  'Add <strong>Modules</strong>' => '',
  'Advanced access settings' => '',
  'All members excluding moderators and administrators of this Space will be removed. All pending invitations and membership requests will be terminated.' => '',
  'Archive' => '',
  'Are you sure you want to remove this member.' => '',
  'Are you sure, that you want to delete this space? All published content will be removed!' => '',
  'As owner of this space you can transfer this role to another administrator in space.' => '',
  'Cancel Membership' => '',
  'Choose if new content should be public or private by default' => '',
  'Choose the kind of membership you want to provide for this workspace.' => '',
  'Choose the modules you want to use for this Space. If you are undecided, you can also activate them later on via the Space settings.' => '',
  'Choose the modules you want to use for this Space. In order for the modules to be available to you here, they must have been previously installed by administrators of the network using the admin panel. If you cannot deactivate individual modules, it is because they have been set as the default for the entire network.' => '',
  'Choose the security level for this workspace to define the visibleness.' => '',
  'Currently there are no modules available for this space!' => '',
  'Delete' => 'Ezabatu',
  'Don\'t receive notifications for new content' => '',
  'Enable' => 'Aktibatu',
  'Hide posts on dashboard' => '',
  'Invited By' => '',
  'Members' => 'Kideak',
  'Modules' => 'Moduluak',
  'Next' => 'Hurrengoa',
  'Only global administrators can change this value' => '',
  'Owner' => '',
  'Pending Approvals' => '',
  'Pending Invites' => '',
  'Permissions are assigned to different user-roles. To edit a permission, select the user-role you want to edit and change the drop-down value of the given permission.' => '',
  'Please type the name of the space to proceed.' => '',
  'Receive Notifications for new content' => '',
  'Removal of members queued' => '',
  'Remove all members' => '',
  'Remove from space' => '',
  'Role' => '',
  'Security' => '',
  'Show all' => 'Erakutsi dena',
  'Show posts on dashboard' => '',
  'Space name' => '',
  'Space owner' => '',
  'Stream (Default)' => '',
  'The URL has already been taken.' => '',
  'The url contains illegal characters!' => '',
  'This option will hide new content from this space at your dashboard' => '',
  'This option will show new content from this space at your dashboard' => '',
  'Transfer ownership' => '',
  'Unarchive' => 'Artxibotik atera',
  'e.g. example for {baseUrl}/s/example' => '',
  'never' => 'Inoiz ez',
);
